@@ -32,11 +32,11 @@ public:
     explicit IncidenceAttribute();
     ~IncidenceAttribute();
 
-    QByteArray type() const Q_DECL_OVERRIDE;
-    Attribute *clone() const Q_DECL_OVERRIDE;
+    QByteArray type() const override;
+    Attribute *clone() const override;
 
-    QByteArray serialized() const Q_DECL_OVERRIDE;
-    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
+    QByteArray serialized() const override;
+    void deserialize(const QByteArray &data) override;
 
     /**
      * The status the invitation is in.
