@@ -22,7 +22,7 @@
 
 #include <TransactionSequence>
 
-#include <QtCore/QString>
+#include <QString>
 
 namespace Akonadi
 {
@@ -60,7 +60,7 @@ public:
 
 protected:
     // reimpl from TransactionSequence
-    void doStart() Q_DECL_OVERRIDE;
+    void doStart() override;
 
 private:
     //@cond PRIVATE
