@@ -34,7 +34,7 @@
 #include <collectiondeletejob.h>
 
 AddCollectionTask::AddCollectionTask(const ResourceStateInterface::Ptr &resource, QObject *parent)
-    : ResourceTask(DeferIfNoSession, resource, parent), m_pendingJobs(0), m_session(Q_NULLPTR)
+    : ResourceTask(DeferIfNoSession, resource, parent), m_pendingJobs(0), m_session(nullptr)
 {
 }
 
@@ -57,7 +57,7 @@ void AddCollectionTask::doStart(KIMAP::Session *session)
     m_pendingJobs = 0;
     m_session = session;
     m_collection = collection();
-    m_collection.setName(m_collection.name().replace(separator, QString()));
+    m_collection.setName(m_collection.name().remove(separator));
     m_collection.setRemoteId(separator + m_collection.name());
 
     QString newMailBox = mailBoxForCollection(parentCollection());
