@@ -33,7 +33,7 @@ public:
     virtual Akonadi::Item createItemFromMessage(const KMime::Message::Ptr &message,
             const qint64 uid,
             const qint64 size,
-            const QList<KIMAP::MessageAttribute> &attrs,
+            const QMap<QByteArray, QVariant> &attrs,
             const QList<QByteArray> &flags,
             const KIMAP::FetchJob::FetchScope &scope,
             bool &ok) const;
