@@ -30,7 +30,7 @@
 #include <Akonadi/KMime/MessageParts>
 #include "kolabresource_debug.h"
 
-KolabResourceState::KolabResourceState(ImapResource *resource, const TaskArguments &arguments)
+KolabResourceState::KolabResourceState(ImapResourceBase *resource, const TaskArguments &arguments)
     : ResourceState(resource, arguments)
 {
 
@@ -91,7 +91,7 @@ void KolabResourceState::collectionAttributesRetrieved(const Akonadi::Collection
 void KolabResourceState::collectionsRetrieved(const Akonadi::Collection::List &collections)
 {
     Akonadi::Collection::List modifiedCollections;
-    Q_FOREACH (const Akonadi::Collection &col, collections) {
+    for (const Akonadi::Collection &col : collections) {
         modifiedCollections << processAnnotations(col);
     }
     ResourceState::collectionsRetrieved(modifiedCollections);
