@@ -49,7 +49,7 @@ public:
     Akonadi::Item::List itemsMarkedAsDeleted() const;
 
 protected:
-    void doStart() Q_DECL_OVERRIDE;
+    void doStart() override;
 
 private:
     class Private;
