@@ -30,35 +30,35 @@ public:
     explicit OpenXchangeResource(const QString &id);
     ~OpenXchangeResource();
 
-    void cleanup() Q_DECL_OVERRIDE;
+    void cleanup() override;
 
 public Q_SLOTS:
-    void configure(WId windowId) Q_DECL_OVERRIDE;
-    void aboutToQuit() Q_DECL_OVERRIDE;
+    void configure(WId windowId) override;
+    void aboutToQuit() override;
 
 protected:
     using ResourceBase::retrieveItems; // Suppress -Woverload-virtual
 
 protected Q_SLOTS:
-    void retrieveCollections() Q_DECL_OVERRIDE;
-    void retrieveItems(const Akonadi::Collection &collection) Q_DECL_OVERRIDE;
-    bool retrieveItem(const Akonadi::Item &item, const QSet<QByteArray> &parts) Q_DECL_OVERRIDE;
+    void retrieveCollections() override;
+    void retrieveItems(const Akonadi::Collection &collection) override;
+    bool retrieveItem(const Akonadi::Item &item, const QSet<QByteArray> &parts) override;
 
 protected:
-    void itemAdded(const Akonadi::Item &item, const Akonadi::Collection &collection) Q_DECL_OVERRIDE;
-    void itemChanged(const Akonadi::Item &item, const QSet<QByteArray> &parts) Q_DECL_OVERRIDE;
-    void itemRemoved(const Akonadi::Item &item) Q_DECL_OVERRIDE;
+    void itemAdded(const Akonadi::Item &item, const Akonadi::Collection &collection) override;
+    void itemChanged(const Akonadi::Item &item, const QSet<QByteArray> &parts) override;
+    void itemRemoved(const Akonadi::Item &item) override;
     virtual void itemMoved(const Akonadi::Item &item, const Akonadi::Collection &collectionSource,
-                           const Akonadi::Collection &collectionDestination) Q_DECL_OVERRIDE;
+                           const Akonadi::Collection &collectionDestination) override;
 
-    void collectionAdded(const Akonadi::Collection &collection, const Akonadi::Collection &parent) Q_DECL_OVERRIDE;
-    void collectionChanged(const Akonadi::Collection &collection) Q_DECL_OVERRIDE;
+    void collectionAdded(const Akonadi::Collection &collection, const Akonadi::Collection &parent) override;
+    void collectionChanged(const Akonadi::Collection &collection) override;
     // do not hide the other variant, use implementation from base class
     // which just forwards to the one above
     using Akonadi::AgentBase::ObserverV2::collectionChanged;
-    void collectionRemoved(const Akonadi::Collection &collection) Q_DECL_OVERRIDE;
+    void collectionRemoved(const Akonadi::Collection &collection) override;
     virtual void collectionMoved(const Akonadi::Collection &collection, const Akonadi::Collection &collectionSource,
-                                 const Akonadi::Collection &collectionDestination) Q_DECL_OVERRIDE;
+                                 const Akonadi::Collection &collectionDestination) override;
 
 private Q_SLOTS:
     void onUpdateUsersJobFinished(KJob *);
