@@ -36,7 +36,7 @@ class ObjectModifyJob : public KJob
 public:
     explicit ObjectModifyJob(const Object &object, QObject *parent = nullptr);
 
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
     Object object() const;
 
