@@ -49,33 +49,33 @@ public:
     virtual void setPath(const QString &path);
     QString path() const;
 
-    Collection topLevelCollection() const Q_DECL_OVERRIDE;
+    Collection topLevelCollection() const override;
 
-    CollectionCreateJob *createCollection(const Collection &collection, const Collection &targetParent) Q_DECL_OVERRIDE;
+    CollectionCreateJob *createCollection(const Collection &collection, const Collection &targetParent) override;
 
-    CollectionFetchJob *fetchCollections(const Collection &collection, CollectionFetchJob::Type type = CollectionFetchJob::FirstLevel) const Q_DECL_OVERRIDE;
+    CollectionFetchJob *fetchCollections(const Collection &collection, CollectionFetchJob::Type type = CollectionFetchJob::FirstLevel) const override;
 
-    CollectionDeleteJob *deleteCollection(const Collection &collection) Q_DECL_OVERRIDE;
+    CollectionDeleteJob *deleteCollection(const Collection &collection) override;
 
-    CollectionModifyJob *modifyCollection(const Collection &collection) Q_DECL_OVERRIDE;
+    CollectionModifyJob *modifyCollection(const Collection &collection) override;
 
-    CollectionMoveJob *moveCollection(const Collection &collection, const Collection &targetParent) Q_DECL_OVERRIDE;
+    CollectionMoveJob *moveCollection(const Collection &collection, const Collection &targetParent) override;
 
-    ItemFetchJob *fetchItems(const Collection &collection) const Q_DECL_OVERRIDE;
+    ItemFetchJob *fetchItems(const Collection &collection) const override;
 
-    ItemFetchJob *fetchItems(const Item::List &items) const Q_DECL_OVERRIDE;
+    ItemFetchJob *fetchItems(const Item::List &items) const override;
 
-    ItemFetchJob *fetchItem(const Item &item) const Q_DECL_OVERRIDE;
+    ItemFetchJob *fetchItem(const Item &item) const override;
 
-    ItemCreateJob *createItem(const Item &item, const Collection &collection) Q_DECL_OVERRIDE;
+    ItemCreateJob *createItem(const Item &item, const Collection &collection) override;
 
-    ItemModifyJob *modifyItem(const Item &item) Q_DECL_OVERRIDE;
+    ItemModifyJob *modifyItem(const Item &item) override;
 
-    ItemDeleteJob *deleteItem(const Item &item) Q_DECL_OVERRIDE;
+    ItemDeleteJob *deleteItem(const Item &item) override;
 
-    ItemMoveJob *moveItem(const Item &item, const Collection &targetParent) Q_DECL_OVERRIDE;
+    ItemMoveJob *moveItem(const Item &item, const Collection &targetParent) override;
 
-    StoreCompactJob *compactStore() Q_DECL_OVERRIDE;
+    StoreCompactJob *compactStore() override;
 
 protected: // job processing
     virtual void processJob(Job *job) = 0;
@@ -89,7 +89,7 @@ protected: // job processing
     void notifyItemsProcessed(const Item::List &items) const;
 
 protected: // template methods
-    void setTopLevelCollection(const Collection &collection) Q_DECL_OVERRIDE;
+    void setTopLevelCollection(const Collection &collection) override;
 
     virtual void checkCollectionCreate(CollectionCreateJob *job, int &errorCode, QString &errorText) const;
 
