@@ -33,7 +33,7 @@ public:
     Akonadi::Collection::List collections() const;
 
     // automatically called by KJob
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
 private Q_SLOTS:
     // This will be called once the request is finished.
